@@ -3,7 +3,7 @@
 #' @author P. Chevallier - Apr 2015 - Aug 2023
 #'
 #' @description Line plot based on htsr time-series. Prior to the execution of the function,
-#' the parameters must be set by a function generating a "settings.RData" file in the working 
+#' the parameters must be set by a function generating a "settings.RData" file in the working
 #' directory: \code{\link{z_set}} or \code{\link{ps_plothts}}.
 
 #' @details The function doesn't have parameter. For a full description of the settings, see \code{\link{z_set}}
@@ -21,23 +21,27 @@ p_line <- function(){
 
 # settings
   fil <- tstab <- Value <- conf <- Legend <- NULL
-  
-	if (!file.exists ("settings.RData")) 
-		warning("A function creating settings.RData in the working dir must be run before p_line()")
 
-	load("settings.RData")
-	
+	if (!file.exists (system.file("extdata/settings.RData",package="htsr")))
+		warning("A function creating settings.RData in the data dir must be run before p_line()")
+
+  options(warn=-1)
+
+	load(file=system.file("extdata/settings.RData",package="htsr"))
+
 	nf <- nrow(fil)
 	pal <- palette.colors(n=nf, palette = palette)
-	
+
+
 # Loop for each track
   for (i in 1:nf) {
-    message("Reading the file ", fil$file.names[i], "\n")
-    load(fil$file.names[i])
+    message("\nReading the file ", fil$file.names[i], "\n")
+  	fff <- fil$file.names[i]
+  	load(file=fff)
     y <- select(tstab, Date, Value)
-    
+
     if (conf[4])  {
-    	y <- filter(y, Date >= as_date(as.numeric(conf[5]))) 
+    	y <- filter(y, Date >= as_date(as.numeric(conf[5])))
     	y <- filter(y, Date <= as_date(as.numeric(conf[6])))
     }
     if (nrow(y)==0)
@@ -54,18 +58,18 @@ p_line <- function(){
   }
 
   # Plotting
-  p <- ggplot (x, aes(x=Date, y= Value, colour = Legend, linewidth = Legend, 
+  p <- ggplot (x, aes(x=Date, y= Value, colour = Legend, linewidth = Legend,
   										linetype = Legend , size = Legend, shape = Legend)) + geom_line(na.rm = TRUE)
   p <- p + scale_colour_manual(values=pal) + scale_linetype_manual(values = fil$line.type) +
     scale_linewidth_manual(values = fil$line.width)
 
   if (conf[10]) p = p + stat_smooth(method=lm, se=FALSE)
 
-  if (conf[11]) p = p + facet_grid (Legend ~ ., scales = "free_y") + 
+  if (conf[11]) p = p + facet_grid (Legend ~ ., scales = "free_y") +
     theme(strip.text = element_text(size=rel(2)),
           strip.background = element_rect(colour="black", size =0.5))
-  
-	if (conf[12]) p = p +  geom_point(na.rm=TRUE) + 
+
+	if (conf[12]) p = p +  geom_point(na.rm=TRUE) +
   	scale_shape_manual(values = fil$point.shape) +
   	scale_size_manual(values = fil$point.size)
 
@@ -86,10 +90,12 @@ p_line <- function(){
   # Redimensionner l'ordonnee
   if(conf[7]==TRUE) p <- p + ylim(as.numeric(conf[8]),as.numeric(conf[9]))
 
-  # Ecriture de l'ordonnee
-  p <- p+ theme(legend.position="bottom") +
-            theme(legend.text=element_text(size =16))
+  # Ecriture des legendes
+  if (conf[11]) p <- p+ theme(legend.position="none")
+  else p <- p+ theme(legend.position="bottom") + theme(legend.text=element_text(size =16))
   p <- p+ theme(legend.title=element_text(size =16, face="bold"))
 
+  options(warn=0)
+
   return(p)
 }
